@@ -49,6 +49,7 @@ public:
         , m_change(change_ms)
         , m_motion(motion_ms)
     {
+        Q_UNUSED(m_plugin);
         // get updated
         m_changeTimer.setSingleShot(true);
         auto ch = [this]() {
@@ -126,6 +127,11 @@ public:
 protected:
     bool lessThan(const QModelIndex &sourceLeft, const QModelIndex &sourceRight) const override
     {
+        // make sure to honour configured sort-order (if no scoring applies)
+        if (m_pattern.isEmpty()) {
+            return QSortFilterProxyModel::lessThan(sourceLeft, sourceRight);
+        }
+
         const int l = sourceLeft.data(WeightRole).toInt();
         const int r = sourceRight.data(WeightRole).toInt();
         return l < r;
@@ -178,6 +184,8 @@ class LSPClientSymbolViewImpl : public QObject, public LSPClientSymbolView
     QScopedPointer<LSPClientViewTracker> m_viewTracker;
     // outstanding request
     LSPClientServer::RequestHandle m_handle;
+    // magic request tracking cookie
+    int m_requestCnt = 0;
     // cached outline models
     struct ModelData {
         QPointer<KTextEditor::Document> document;
@@ -265,7 +273,7 @@ public:
         m_viewTracker.reset(LSPClientViewTracker::new_(plugin, mainWin, 500, 100));
         connect(m_viewTracker.data(), &LSPClientViewTracker::newState, this, &self_type::onViewState);
         connect(m_serverManager.data(), &LSPClientServerManager::serverChanged, this, [this]() {
-            refresh(false);
+            refresh(false, false);
         });
 
         // limit cached models; will not go beyond capacity set here
@@ -278,7 +286,7 @@ public:
     void displayOptionChanged()
     {
         m_expandOn->setEnabled(m_treeOn->isChecked());
-        refresh(false);
+        refresh(false, false);
     }
 
     void configUpdated()
@@ -450,7 +458,7 @@ public:
         updateCurrentTreeItem();
     }
 
-    void refresh(bool clear)
+    void refresh(bool clear, bool allow_cache = true, int retry = 0)
     {
         // cancel old request!
         m_handle.cancel();
@@ -487,7 +495,7 @@ public:
                 // re-use if possible
                 // reloaded document recycles revision number, so avoid stale cache
                 // (clear := view switch)
-                if (revision == model.revision && model.model && (clear || revision > 0)) {
+                if (revision == model.revision && model.model && (clear || revision > 0) && allow_cache) {
                     setModel(model.model);
                     return;
                 }
@@ -503,13 +511,25 @@ public:
             // so arrange to process it as an error rather than an empty result,
             // since the latter would (temporarily) clear the symbol outline
             // and lead to flicker until the next/final request has a proper result again
-            auto eh = [this](const LSPResponseError &err) {
+            auto oldRequestCnt = ++m_requestCnt;
+            auto eh = [this, clear, retry, oldRequestCnt](const LSPResponseError &err) {
                 switch (err.code) {
                 case LSPErrorCode::ContentModified:
                 case LSPErrorCode::RequestCancelled:
                     break;
                 default:
-                    onDocumentSymbols({});
+                    // also try to avoid flicker here
+                    // never mind the request if another one has already been launched
+                    // but if this is the last request standing, go for retry
+                    if (m_requestCnt == oldRequestCnt) {
+                        if (retry < 4) {
+                            // if we got here, cache was not used
+                            refresh(clear, false, retry + 1);
+                        } else {
+                            // clear old/stale situation and show that the server has lost track
+                            onDocumentSymbols({});
+                        }
+                    }
                     break;
                 }
             };
