@@ -7,8 +7,8 @@
 #define GITUTILS_H
 
 #include <QString>
-
 #include <functional>
+#include <optional>
 
 namespace GitUtils
 {
@@ -57,7 +57,7 @@ bool isGitRepo(const QString &repo);
  *
  * Can be used to check whether you are in a git repo as well
  */
-QString getDotGitPath(const QString &repo);
+std::optional<QString> getDotGitPath(const QString &repo);
 
 /**
  * @brief get name of current branch in @p repo
@@ -83,6 +83,8 @@ QVector<Branch> getAllBranches(const QString &repo);
  * @brief get all local and remote branches + tags
  */
 QVector<Branch> getAllBranchesAndTags(const QString &repo, RefType ref = RefType::All);
+
+std::pair<QString, QString> getLastCommitMessage(const QString &repo);
 }
 
 Q_DECLARE_TYPEINFO(GitUtils::Branch, Q_MOVABLE_TYPE);
