@@ -11,6 +11,7 @@
 #include "gitcommitdialog.h"
 #include "gitstatusmodel.h"
 #include "kateproject.h"
+#include "kateprojectplugin.h"
 #include "kateprojectpluginview.h"
 #include "pushpulldialog.h"
 #include "stashdialog.h"
@@ -165,16 +166,16 @@ GitWidget::GitWidget(KateProject *project, KTextEditor::MainWindow *mainWindow,
         m_menuBtn->showMenu();
     });
 
-    m_commitBtn = toolButton(QStringLiteral("svn-commit"), QString(), i18n("Commit"), Qt::ToolButtonTextBesideIcon);
+    m_commitBtn = toolButton(QStringLiteral("vcs-commit"), QString(), i18n("Commit"), Qt::ToolButtonTextBesideIcon);
 
-    m_pushBtn = toolButton(QStringLiteral("arrow-up"), i18n("Git push"));
+    m_pushBtn = toolButton(QStringLiteral("vcs-push"), i18n("Git push"));
     connect(m_pushBtn, &QToolButton::clicked, this, [this]() {
         PushPullDialog ppd(m_mainWin->window(), m_gitPath);
         connect(&ppd, &PushPullDialog::runGitCommand, this, &GitWidget::runPushPullCmd);
         ppd.openDialog(PushPullDialog::Push);
     });
 
-    m_pullBtn = toolButton(QStringLiteral("arrow-down"), i18n("Git pull"));
+    m_pullBtn = toolButton(QStringLiteral("vcs-pull"), i18n("Git pull"));
     connect(m_pullBtn, &QToolButton::clicked, this, [this]() {
         PushPullDialog ppd(m_mainWin->window(), m_gitPath);
         connect(&ppd, &PushPullDialog::runGitCommand, this, &GitWidget::runPushPullCmd);
@@ -232,7 +233,7 @@ GitWidget::GitWidget(KateProject *project, KTextEditor::MainWindow *mainWindow,
     m_mainView->setLayout(layout);
 
     connect(&m_gitStatusWatcher, &QFutureWatcher<GitUtils::GitParsedStatus>::finished, this, &GitWidget::parseStatusReady);
-    connect(m_commitBtn, &QPushButton::clicked, this, &GitWidget::opencommitChangesDialog);
+    connect(m_commitBtn, &QPushButton::clicked, this, &GitWidget::openCommitChangesDialog);
 
     // single / double click
     connect(m_treeView, &QTreeView::clicked, this, &GitWidget::treeViewSingleClicked);
@@ -250,39 +251,28 @@ GitWidget::~GitWidget()
     if (m_cancelHandle) {
         m_cancelHandle->kill();
     }
+
+    // if there are any living processes, disconnect them now before gitwidget get destroyed
+    for (QObject *child : children()) {
+        QProcess *p = qobject_cast<QProcess *>(child);
+        if (p) {
+            disconnect(p, nullptr, nullptr, nullptr);
+        }
+    }
 }
 
 void GitWidget::setDotGitPath()
 {
-    /* This call is intentionally blocking because we need git path for everything else */
-    QProcess git;
-    git.setProgram(QStringLiteral("git"));
-    git.setWorkingDirectory(m_project->baseDir());
-    git.setArguments({QStringLiteral("rev-parse"), QStringLiteral("--absolute-git-dir")});
-    git.start(QProcess::ReadOnly);
-    if (git.waitForStarted() && git.waitForFinished(-1)) {
-        if (git.exitStatus() != QProcess::NormalExit || git.exitCode() != 0) {
-            const QString error = QString::fromUtf8(git.readAllStandardError());
-
-            /**
-             * Do this on next even loop iteration because we may be in the constructor of pluginView
-             */
-            QTimer::singleShot(1, this, [this, error] {
-                sendMessage(i18n("Failed to find .git directory, things may not work correctly: %1", error), false);
-            });
-            m_gitPath = m_project->baseDir();
-            return;
-        }
-        m_gitPath = QString::fromUtf8(git.readAllStandardOutput());
-        if (m_gitPath.endsWith(QLatin1String("\n"))) {
-            m_gitPath.remove(QLatin1String(".git\n"));
-        } else {
-            m_gitPath.remove(QLatin1String(".git"));
-        }
-        // set once, use everywhere
-        // This is per project
-        git.setWorkingDirectory(m_gitPath);
+    const auto dotGitPath = GitUtils::getDotGitPath(m_project->baseDir());
+    if (!dotGitPath.has_value()) {
+        QTimer::singleShot(1, this, [this] {
+            sendMessage(i18n("Failed to find .git directory, things may not work correctly"), false);
+        });
+        m_gitPath = m_project->baseDir();
+        return;
     }
+
+    m_gitPath = dotGitPath.value();
 }
 
 void GitWidget::sendMessage(const QString &plainText, bool warn)
@@ -534,12 +524,18 @@ void GitWidget::launchExternalDiffTool(const QString &file, bool staged)
     git.startDetached(QStringLiteral("git"), args, m_gitPath);
 }
 
-void GitWidget::commitChanges(const QString &msg, const QString &desc, bool signOff)
+void GitWidget::commitChanges(const QString &msg, const QString &desc, bool signOff, bool amend)
 {
     auto args = QStringList{QStringLiteral("commit")};
+
+    if (amend) {
+        args.append(QStringLiteral("--amend"));
+    }
+
     if (signOff) {
         args.append(QStringLiteral("-s"));
     }
+
     args.append(QStringLiteral("-m"));
     args.append(msg);
     if (!desc.isEmpty()) {
@@ -625,9 +621,9 @@ void GitWidget::applyDiff(const QString &fileName, bool staged, bool hunk, KText
     git->start(QProcess::ReadOnly);
 }
 
-void GitWidget::opencommitChangesDialog()
+void GitWidget::openCommitChangesDialog(bool amend)
 {
-    if (m_model->stagedFiles().isEmpty()) {
+    if (!amend && m_model->stagedFiles().isEmpty()) {
         return sendMessage(i18n("Nothing to commit. Please stage your changes first."), true);
     }
 
@@ -641,6 +637,10 @@ void GitWidget::opencommitChangesDialog()
 
     GitCommitDialog *dialog = new GitCommitDialog(m_commitMessage, font, this);
 
+    if (amend) {
+        dialog->setAmendingCommit();
+    }
+
     connect(dialog, &QDialog::finished, this, [this, dialog](int res) {
         dialog->deleteLater();
         if (res == QDialog::Accepted) {
@@ -648,7 +648,7 @@ void GitWidget::opencommitChangesDialog()
                 return sendMessage(i18n("Commit message cannot be empty."), true);
             }
             m_commitMessage = dialog->subject() + QStringLiteral("[[\n\n]]") + dialog->description();
-            commitChanges(dialog->subject(), dialog->description(), dialog->signoff());
+            commitChanges(dialog->subject(), dialog->description(), dialog->signoff(), dialog->amendingLastCommit());
         }
     });
 
@@ -765,6 +765,7 @@ void GitWidget::branchCompareFiles(const QString &from, const QString &to)
 
     const QByteArray diff = git.readAllStandardOutput();
     if (diff.isEmpty()) {
+        sendMessage(i18n("No diff for %1...%2", from, to), false);
         return;
     }
 
@@ -814,25 +815,34 @@ bool GitWidget::eventFilter(QObject *o, QEvent *e)
 void GitWidget::buildMenu()
 {
     m_gitMenu = new QMenu(this);
-    m_gitMenu->addAction(i18n("Refresh"), this, [this] {
+    auto r = m_gitMenu->addAction(i18n("Refresh"), this, [this] {
         if (m_project) {
             getStatus();
         }
     });
-    m_gitMenu->addAction(i18n("Checkout Branch"), this, [this] {
+    r->setIcon(QIcon::fromTheme(QStringLiteral("view-refresh")));
+
+    m_gitMenu->addAction(QIcon::fromTheme(QStringLiteral("document-edit")), i18n("Amend Last Commit"), this, [this] {
+        openCommitChangesDialog(/* amend = */ true);
+    });
+
+    auto a = m_gitMenu->addAction(i18n("Checkout Branch"), this, [this] {
         BranchCheckoutDialog bd(m_mainWin->window(), m_pluginView, m_project->baseDir());
         bd.openDialog();
     });
+    a->setIcon(QIcon::fromTheme(QStringLiteral("vcs-branch")));
 
-    m_gitMenu->addAction(i18n("Compare Branch with ..."), this, [this] {
+    a = m_gitMenu->addAction(i18n("Compare Branch with ..."), this, [this] {
         BranchesDialog bd(m_mainWin->window(), m_pluginView, m_project->baseDir());
         using GitUtils::RefType;
         bd.openDialog(static_cast<GitUtils::RefType>(RefType::Head | RefType::Remote));
         QString branch = bd.branch();
         branchCompareFiles(branch, QString());
     });
+    a->setIcon(QIcon::fromTheme(QStringLiteral("vcs-diff")));
 
-    m_gitMenu->addAction(i18n("Stash"))->setMenu(stashMenu());
+    auto stashMenu = m_gitMenu->addAction(QIcon::fromTheme(QStringLiteral("vcs-stash")), i18n("Stash"));
+    stashMenu->setMenu(this->stashMenu());
 }
 
 void GitWidget::createStashDialog(StashMode m, const QString &gitPath)
@@ -865,12 +875,12 @@ void GitWidget::hideCancel()
 QMenu *GitWidget::stashMenu()
 {
     QMenu *menu = new QMenu(this);
-    auto stashAct = menu->addAction(i18n("Stash"));
-    auto popLastAct = menu->addAction(i18n("Pop Last Stash"));
-    auto popAct = menu->addAction(i18n("Pop Stash"));
+    auto stashAct = menu->addAction(QIcon::fromTheme(QStringLiteral("vcs-stash")), i18n("Stash"));
+    auto popLastAct = menu->addAction(QIcon::fromTheme(QStringLiteral("vcs-stash-pop")), i18n("Pop Last Stash"));
+    auto popAct = menu->addAction(QIcon::fromTheme(QStringLiteral("vcs-stash-pop")), i18n("Pop Stash"));
     auto applyLastAct = menu->addAction(i18n("Apply Last Stash"));
-    auto stashKeepStagedAct = menu->addAction(i18n("Stash (Keep Staged)"));
-    auto stashUAct = menu->addAction(i18n("Stash (Include Untracked)"));
+    auto stashKeepStagedAct = menu->addAction(QIcon::fromTheme(QStringLiteral("vcs-stash")), i18n("Stash (Keep Staged)"));
+    auto stashUAct = menu->addAction(QIcon::fromTheme(QStringLiteral("vcs-stash")), i18n("Stash (Include Untracked)"));
     auto applyStashAct = menu->addAction(i18n("Apply Stash"));
     auto dropAct = menu->addAction(i18n("Drop Stash"));
     auto showStashAct = menu->addAction(i18n("Show Stash Content"));
@@ -924,11 +934,15 @@ void GitWidget::treeViewContextMenuEvent(QContextMenuEvent *e)
 
     if (type == GitStatusModel::NodeChanges || type == GitStatusModel::NodeUntrack) {
         QMenu menu;
-        auto stageAct = menu.addAction(i18n("Stage All"));
         bool untracked = type == GitStatusModel::NodeUntrack;
+
+        auto stageAct = menu.addAction(i18n("Stage All"));
+
         auto discardAct = untracked ? menu.addAction(i18n("Remove All")) : menu.addAction(i18n("Discard All"));
+        discardAct->setIcon(QIcon::fromTheme(QStringLiteral("edit-delete-remove")));
+
         auto ignoreAct = untracked ? menu.addAction(i18n("Open .gitignore")) : nullptr;
-        auto diff = !untracked ? menu.addAction(i18n("Show diff")) : nullptr;
+        auto diff = !untracked ? menu.addAction(QIcon::fromTheme(QStringLiteral("vcs-diff")), i18n("Show diff")) : nullptr;
         // get files
         auto act = menu.exec(m_treeView->viewport()->mapToGlobal(e->pos()));
         if (!act) {
@@ -974,11 +988,14 @@ void GitWidget::treeViewContextMenuEvent(QContextMenuEvent *e)
         bool untracked = idx.internalId() == GitStatusModel::NodeUntrack;
 
         auto openFile = menu.addAction(i18n("Open file"));
-        auto showDiffAct = untracked ? nullptr : menu.addAction(i18n("Show raw diff"));
-        auto launchDifftoolAct = untracked ? nullptr : menu.addAction(i18n("Show in external git diff tool"));
+        auto showDiffAct = untracked ? nullptr : menu.addAction(QIcon::fromTheme(QStringLiteral("vcs-diff")), i18n("Show raw diff"));
+        auto launchDifftoolAct = untracked ? nullptr : menu.addAction(QIcon::fromTheme(QStringLiteral("kdiff3")), i18n("Show in external git diff tool"));
         auto openAtHead = untracked ? nullptr : menu.addAction(i18n("Open at HEAD"));
         auto stageAct = staged ? menu.addAction(i18n("Unstage file")) : menu.addAction(i18n("Stage file"));
         auto discardAct = staged ? nullptr : untracked ? menu.addAction(i18n("Remove")) : menu.addAction(i18n("Discard"));
+        if (discardAct) {
+            discardAct->setIcon(QIcon::fromTheme(QStringLiteral("edit-delete-remove")));
+        }
 
         auto act = menu.exec(m_treeView->viewport()->mapToGlobal(e->pos()));
         if (!act) {
@@ -1069,6 +1086,9 @@ void GitWidget::selectedContextMenu(QContextMenuEvent *e)
     QMenu menu;
     auto stageAct = selectionHasStagedItems ? menu.addAction(i18n("Unstage Selected Files")) : menu.addAction(i18n("Stage Selected Files"));
     auto discardAct = selectionHasChangedItems && !selectionHasUntrackedItems ? menu.addAction(i18n("Discard Selected Files")) : nullptr;
+    if (discardAct) {
+        discardAct->setIcon(QIcon::fromTheme(QStringLiteral("edit-delete-remove")));
+    }
     auto removeAct = !selectionHasChangedItems && selectionHasUntrackedItems ? menu.addAction(i18n("Remove Selected Files")) : nullptr;
     auto execAct = menu.exec(m_treeView->viewport()->mapToGlobal(e->pos()));
     if (!execAct) {
