@@ -8,19 +8,18 @@
 #ifndef KATE_PROJECT_INFO_VIEW_TERMINAL_H
 #define KATE_PROJECT_INFO_VIEW_TERMINAL_H
 
-#include "kateproject.h"
-
 #include <QKeyEvent>
 #include <QVBoxLayout>
 
-#include <KPluginFactory>
-#include <kparts/part.h>
+#include <kparts/readonlypart.h>
+
+#include <QWidget>
 
 class KateProjectPluginView;
+class KPluginFactory;
 
 /**
- * Class representing a view of a project.
- * A tree like view of project content.
+ * Single terminal view for project toolview
  */
 class KateProjectInfoViewTerminal : public QWidget
 {
@@ -39,13 +38,6 @@ public:
      */
     ~KateProjectInfoViewTerminal() override;
 
-    /**
-     * global plugin factory to create terminal
-     * exposed to allow to skip terminal toolview creation if not possible
-     * @return plugin factory for terminal or nullptr if no terminal part there
-     */
-    static KPluginFactory *pluginFactory();
-
     /**
      * Shall the ESC key press be ignored?
      * If not, the toolview will be hidden.
@@ -53,6 +45,13 @@ public:
      */
     bool ignoreEsc() const;
 
+    /**
+     * Check if terminal is loadable
+     */
+    static bool isLoadable();
+
+    void respawn(const QString &dirPath);
+
 private Q_SLOTS:
     /**
      * Construct a new terminal for this view
@@ -71,6 +70,14 @@ protected:
      */
     void showEvent(QShowEvent *ev) override;
 
+private:
+    /**
+     * global plugin factory to create terminal
+     * exposed to allow to skip terminal toolview creation if not possible
+     * @return plugin factory for terminal or nullptr if no terminal part there
+     */
+    static KPluginFactory *pluginFactory();
+
 private:
     /**
      * plugin factory for the terminal
@@ -85,7 +92,7 @@ private:
     /**
      * our start directory for the terminal
      */
-    const QString m_directory;
+    QString m_directory;
 
     /**
      * our layout
