@@ -8,8 +8,13 @@
 #include "kateprojectpluginview.h"
 #include "fileutil.h"
 #include "gitwidget.h"
+#include "kateproject.h"
+#include "kateprojectinfoview.h"
 #include "kateprojectinfoviewindex.h"
+#include "kateprojectplugin.h"
+#include "kateprojectview.h"
 
+#include <KTextEditor/Command>
 #include <ktexteditor/application.h>
 #include <ktexteditor/codecompletioninterface.h>
 #include <ktexteditor/document.h>
@@ -33,6 +38,8 @@
 #include <QTimer>
 #include <QVBoxLayout>
 
+#define PROJECTCLOSEICON "window-close"
+
 K_PLUGIN_FACTORY_WITH_JSON(KateProjectPluginFactory, "kateprojectplugin.json", registerPlugin<KateProjectPlugin>();)
 
 KateProjectPluginView::KateProjectPluginView(KateProjectPlugin *plugin, KTextEditor::MainWindow *mainWin)
@@ -76,10 +83,14 @@ KateProjectPluginView::KateProjectPluginView(KateProjectPlugin *plugin, KTextEdi
     m_reloadButton = new QToolButton(m_toolView);
     m_reloadButton->setAutoRaise(true);
     m_reloadButton->setIcon(QIcon::fromTheme(QStringLiteral("view-refresh")));
+    m_closeProjectButton = new QToolButton(m_toolView);
+    m_closeProjectButton->setAutoRaise(true);
+    m_closeProjectButton->setIcon(QIcon::fromTheme(QStringLiteral(PROJECTCLOSEICON)));
     QHBoxLayout *layout = new QHBoxLayout();
     layout->setSpacing(0);
     layout->addWidget(m_projectsCombo);
     layout->addWidget(m_reloadButton);
+    layout->addWidget(m_closeProjectButton);
     m_toolView->layout()->addItem(layout);
     m_toolView->layout()->setSpacing(0);
 
@@ -108,6 +119,10 @@ KateProjectPluginView::KateProjectPluginView(KateProjectPlugin *plugin, KTextEdi
     });
     connect(m_projectsCombo, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &KateProjectPluginView::slotCurrentChanged);
     connect(m_reloadButton, &QToolButton::clicked, this, &KateProjectPluginView::slotProjectReload);
+
+    connect(m_closeProjectButton, &QToolButton::clicked, this, &KateProjectPluginView::slotProjectAboutToClose);
+    connect(m_plugin, &KateProjectPlugin::pluginViewProjectClosing, this, &KateProjectPluginView::slotProjectClose);
+
     connect(m_gitStatusRefreshButton, &QToolButton::clicked, this, [this] {
         if (auto widget = m_stackedgitViews->currentWidget()) {
             qobject_cast<GitWidget *>(widget)->getStatus();
@@ -160,13 +175,23 @@ KateProjectPluginView::KateProjectPluginView(KateProjectPlugin *plugin, KTextEdi
      */
     auto a = actionCollection()->addAction(QStringLiteral("projects_open_project"), this, SLOT(openDirectoryOrProject()));
     a->setText(i18n("Open Folder..."));
+
+    a = actionCollection()->addAction(QStringLiteral("projects_todos"), this, SLOT(showProjectTodos()));
+    a->setText(i18n("Project TODOs"));
+    a->setIcon(QIcon::fromTheme(QStringLiteral("korg-todo")));
+
     a = actionCollection()->addAction(KStandardAction::Back, QStringLiteral("projects_prev_project"), this, SLOT(slotProjectPrev()));
     actionCollection()->setDefaultShortcut(a, QKeySequence(Qt::CTRL | Qt::ALT | Qt::Key_Left));
+
     a = actionCollection()->addAction(KStandardAction::Forward, QStringLiteral("projects_next_project"), this, SLOT(slotProjectNext()));
     actionCollection()->setDefaultShortcut(a, QKeySequence(Qt::CTRL | Qt::ALT | Qt::Key_Right));
+
     a = actionCollection()->addAction(QStringLiteral("projects_goto_index"), this, SLOT(slotProjectIndex()));
     a->setText(i18n("Lookup"));
     actionCollection()->setDefaultShortcut(a, QKeySequence(Qt::ALT | Qt::Key_1));
+    a = actionCollection()->addAction(QStringLiteral("projects_close"), this, SLOT(slotProjectAboutToClose()));
+    a->setText(i18n("Close Project"));
+    a->setIcon(QIcon::fromTheme(QStringLiteral(PROJECTCLOSEICON)));
     m_gotoSymbolActionAppMenu = a = actionCollection()->addAction(KStandardAction::Goto, QStringLiteral("projects_goto_symbol"), this, SLOT(slotGotoSymbol()));
 
     // popup menu
@@ -273,6 +298,11 @@ QPair<KateProjectView *, KateProjectInfoView *> KateProjectPluginView::viewForPr
     m_projectsCombo->addItem(QIcon::fromTheme(QStringLiteral("project-open")), project->name(), project->fileName());
     m_projectsComboGit->addItem(QIcon::fromTheme(QStringLiteral("project-open")), project->name(), project->fileName());
 
+    /*
+     * inform onward
+     */
+    Q_EMIT pluginProjectAdded(project->baseDir(), project->name());
+
     /**
      * remember and return it
      */
@@ -362,6 +392,17 @@ QStringList KateProjectPluginView::allProjectsFiles() const
     return fileList;
 }
 
+QMap<QString, QString> KateProjectPluginView::allProjects() const
+{
+    QMap<QString, QString> projectMap;
+
+    const auto projectList = m_plugin->projects();
+    for (auto project : projectList) {
+        projectMap[project->baseDir()] = project->name();
+    }
+    return projectMap;
+}
+
 void KateProjectPluginView::slotViewChanged()
 {
     /**
@@ -558,6 +599,37 @@ void KateProjectPluginView::slotProjectReload()
     }
 }
 
+void KateProjectPluginView::slotProjectAboutToClose()
+{
+    if (QWidget *current = m_stackedProjectViews->currentWidget()) {
+        m_plugin->closeProject(static_cast<KateProjectView *>(current)->project());
+    }
+}
+
+void KateProjectPluginView::slotProjectClose(KateProject *project)
+{
+    const int index = m_plugin->projects().indexOf(project);
+    m_project2View.erase(m_project2View.find(project));
+
+    QWidget *stackedProjectViewsWidget = m_stackedProjectViews->widget(index);
+    m_stackedProjectViews->removeWidget(stackedProjectViewsWidget);
+    delete stackedProjectViewsWidget;
+
+    QWidget *stackedProjectInfoViewsWidget = m_stackedProjectInfoViews->widget(index);
+    m_stackedProjectInfoViews->removeWidget(stackedProjectInfoViewsWidget);
+    delete stackedProjectInfoViewsWidget;
+
+    QWidget *stackedgitViewsWidget = m_stackedgitViews->widget(index);
+    m_stackedgitViews->removeWidget(stackedgitViewsWidget);
+    delete stackedgitViewsWidget;
+
+    m_projectsCombo->removeItem(index);
+    m_projectsComboGit->removeItem(index);
+
+    // inform onward
+    Q_EMIT pluginProjectRemoved(project->baseDir(), project->name());
+}
+
 QString KateProjectPluginView::currentWord() const
 {
     KTextEditor::View *kv = m_activeTextEditorView;
@@ -654,4 +726,40 @@ void KateProjectPluginView::openDirectoryOrProject()
     }
 }
 
+void KateProjectPluginView::showProjectTodos()
+{
+    KTextEditor::Command *pgrep = KTextEditor::Editor::instance()->queryCommand(QStringLiteral("pgrep"));
+    if (!pgrep) {
+        return;
+    }
+    QString msg;
+    pgrep->exec(nullptr, QStringLiteral("preg (TODO|FIXME)\\b"), msg);
+}
+
+void KateProjectPluginView::showDiffInFixedView(const QByteArray &contents)
+{
+    if (!m_fixedView.view) {
+        m_fixedView.view = mainWindow()->openUrl(QUrl());
+        m_fixedView.defaultMenu = m_fixedView.view->contextMenu();
+    }
+
+    m_fixedView.view->document()->setText(QString::fromUtf8(contents));
+    m_fixedView.view->document()->setHighlightingMode(QStringLiteral("Diff"));
+    /** We don't want save dialog on close */
+    m_fixedView.view->document()->setModified(false);
+    m_fixedView.view->setCursorPosition({0, 0});
+    m_fixedView.restoreMenu();
+    /** Activate this view */
+    m_mainWindow->activateView(m_fixedView.view->document());
+}
+
+void KateProjectPluginView::openTerminal(const QString &dirPath, KateProject *project)
+{
+    m_mainWindow->showToolView(m_toolInfoView);
+
+    if (m_project2View.contains(project)) {
+        m_project2View.find(project)->second->resetTerminal(dirPath);
+    }
+}
+
 #include "kateprojectpluginview.moc"
