@@ -221,6 +221,9 @@ QObject *KatePluginSearch::createView(KTextEditor::MainWindow *mainWindow)
     connect(m_searchCommand, &KateSearchCommand::setCurrentFolder, view, &KatePluginSearchView::setCurrentFolder);
     connect(m_searchCommand, &KateSearchCommand::setSearchString, view, &KatePluginSearchView::setSearchString);
     connect(m_searchCommand, &KateSearchCommand::startSearch, view, &KatePluginSearchView::startSearch);
+    connect(m_searchCommand, &KateSearchCommand::setRegexMode, view, &KatePluginSearchView::setRegexMode);
+    connect(m_searchCommand, &KateSearchCommand::setCaseInsensitive, view, &KatePluginSearchView::setCaseInsensitive);
+    connect(m_searchCommand, &KateSearchCommand::setExpandResults, view, &KatePluginSearchView::setExpandResults);
     connect(m_searchCommand, SIGNAL(newTab()), view, SLOT(addTab()));
 
     connect(view, &KatePluginSearchView::searchBusy, m_searchCommand, &KateSearchCommand::setBusy);
@@ -340,7 +343,7 @@ KatePluginSearchView::KatePluginSearchView(KTextEditor::Plugin *plugin, KTextEdi
     connect(container, &ContainerWidget::nextFocus, this, &KatePluginSearchView::nextFocus);
 
     QAction *a = actionCollection()->addAction(QStringLiteral("search_in_files"));
-    actionCollection()->setDefaultShortcut(a, QKeySequence(Qt::CTRL | Qt::ALT | Qt::Key_F));
+    actionCollection()->setDefaultShortcut(a, QKeySequence(Qt::CTRL | Qt::SHIFT | Qt::Key_F));
     a->setText(i18n("Search in Files"));
     connect(a, &QAction::triggered, this, &KatePluginSearchView::openSearchView);
 
@@ -360,6 +363,8 @@ KatePluginSearchView::KatePluginSearchView(KTextEditor::Plugin *plugin, KTextEdi
     actionCollection()->setDefaultShortcut(a, QKeySequence(Qt::SHIFT | Qt::Key_F6));
     connect(a, &QAction::triggered, this, &KatePluginSearchView::goToPreviousMatch);
 
+    // Only show the tab bar when there is more than one tab
+    m_ui.resultTabWidget->tabBar()->setAutoHide(true);
     m_ui.resultTabWidget->tabBar()->setSelectionBehaviorOnRemove(QTabBar::SelectLeftTab);
     KAcceleratorManager::setNoAccel(m_ui.resultTabWidget);
 
@@ -386,9 +391,7 @@ KatePluginSearchView::KatePluginSearchView(KTextEditor::Plugin *plugin, KTextEdi
     m_ui.filterCombo->setToolTip(i18n("Comma separated list of file types to search in. Example: \"*.cpp,*.h\"\n"));
     m_ui.excludeCombo->setToolTip(i18n("Comma separated list of files and directories to exclude from the search. Example: \"build*\""));
 
-    // the order here is important to get the tabBar hidden for only one tab
     addTab();
-    m_ui.resultTabWidget->tabBar()->hide();
 
     // get url-requester's combo box and sanely initialize
     KComboBox *cmbUrl = m_ui.folderRequester->comboBox();
@@ -448,6 +451,10 @@ KatePluginSearchView::KatePluginSearchView(KTextEditor::Plugin *plugin, KTextEdi
     m_diskSearchDoneTimer.setInterval(10);
     connect(&m_diskSearchDoneTimer, &QTimer::timeout, this, &KatePluginSearchView::searchDone);
 
+    m_updateCheckedStateTimer.setSingleShot(true);
+    m_updateCheckedStateTimer.setInterval(10);
+    connect(&m_updateCheckedStateTimer, &QTimer::timeout, this, &KatePluginSearchView::updateMatchMarks);
+
     // queued connect to signals emitted outside of background thread
     connect(&m_folderFilesList, &FolderFilesList::fileListReady, this, &KatePluginSearchView::folderFileListChanged, Qt::QueuedConnection);
     connect(
@@ -646,6 +653,11 @@ void KatePluginSearchView::handleEsc(QEvent *e)
         } else if (m_toolView->isVisible()) {
             m_mainWindow->hideToolView(m_toolView);
         }
+        // uncheck all so no new marks are added again when switching views
+        Results *curResults = qobject_cast<Results *>(m_ui.resultTabWidget->currentWidget());
+        if (curResults) {
+            curResults->matchModel.uncheckAll();
+        }
     }
 }
 
@@ -975,10 +987,15 @@ void KatePluginSearchView::startSearch()
         return;
     }
 
-    QRegularExpression::PatternOptions patternOptions =
-        (m_ui.matchCase->isChecked() ? QRegularExpression::UseUnicodePropertiesOption
-                                     : QRegularExpression::UseUnicodePropertiesOption | QRegularExpression::CaseInsensitiveOption);
     QString pattern = (m_ui.useRegExp->isChecked() ? currentSearchText : QRegularExpression::escape(currentSearchText));
+    QRegularExpression::PatternOptions patternOptions = QRegularExpression::UseUnicodePropertiesOption;
+    if (!m_ui.matchCase->isChecked()) {
+        patternOptions |= QRegularExpression::CaseInsensitiveOption;
+    }
+
+    if (pattern.contains(QLatin1String("\\n"))) {
+        patternOptions |= QRegularExpression::MultilineOption;
+    }
     QRegularExpression reg(pattern, patternOptions);
 
     if (!reg.isValid()) {
@@ -1145,11 +1162,16 @@ void KatePluginSearchView::startSearchWhileTyping()
 
     // Now we should have a true typed text change
 
-    QRegularExpression::PatternOptions patternOptions =
-        (m_ui.matchCase->isChecked() ? QRegularExpression::UseUnicodePropertiesOption
-                                     : QRegularExpression::UseUnicodePropertiesOption | QRegularExpression::CaseInsensitiveOption);
     QString pattern = (m_ui.useRegExp->isChecked() ? currentSearchText : QRegularExpression::escape(currentSearchText));
+    QRegularExpression::PatternOptions patternOptions = QRegularExpression::UseUnicodePropertiesOption;
+    if (!m_ui.matchCase->isChecked()) {
+        patternOptions |= QRegularExpression::CaseInsensitiveOption;
+    }
+    if (pattern.contains(QLatin1String("\\n"))) {
+        patternOptions |= QRegularExpression::MultilineOption;
+    }
     QRegularExpression reg(pattern, patternOptions);
+
     if (!reg.isValid()) {
         // qDebug() << "invalid regexp";
         indicateMatch(false);
@@ -1476,7 +1498,7 @@ void KatePluginSearchView::addRangeAndMark(KTextEditor::Document *doc,
                                            KTextEditor::Attribute::Ptr attr,
                                            KTextEditor::MovingInterface *miface)
 {
-    if (!doc) {
+    if (!doc || !match.checked) {
         return;
     }
 
@@ -1511,8 +1533,8 @@ void KatePluginSearchView::addRangeAndMark(KTextEditor::Document *doc,
     }
 
     KTextEditor::MovingRange *mr = miface->newMovingRange(match.range);
-    mr->setAttribute(attr);
     mr->setZDepth(-90000.0); // Set the z-depth to slightly worse than the selection
+    mr->setAttribute(attr);
     mr->setAttributeOnlyForViews(true);
     m_matchRanges.append(mr);
 
@@ -1527,6 +1549,22 @@ void KatePluginSearchView::addRangeAndMark(KTextEditor::Document *doc,
     iface->addMark(match.range.start().line(), KTextEditor::MarkInterface::markType32);
 }
 
+void KatePluginSearchView::updateCheckState(const QModelIndex &topLeft, const QModelIndex &bottomRight, const QVector<int> &roles)
+{
+    Q_UNUSED(topLeft);
+    Q_UNUSED(bottomRight);
+
+    // check tailored to the way signal is raised by the model
+    // keep the check simple in case each one is one of many
+    if (roles.size() == 0 || roles.size() > 1 || roles[0] != Qt::CheckStateRole) {
+        return;
+    }
+    // more updates might follow, let's batch those
+    if (!m_updateCheckedStateTimer.isActive()) {
+        m_updateCheckedStateTimer.start();
+    }
+}
+
 void KatePluginSearchView::updateMatchMarks()
 {
     // We only keep marks & ranges for one document at a time so clear the rest
@@ -1554,6 +1592,8 @@ void KatePluginSearchView::updateMatchMarks()
     // clang-format on
     // Re-add the highlighting on document reload
     connect(doc, &KTextEditor::Document::reloaded, this, &KatePluginSearchView::updateMatchMarks, Qt::UniqueConnection);
+    // Re-do highlight upon check mark update
+    connect(&res->matchModel, &QAbstractItemModel::dataChanged, this, &KatePluginSearchView::updateCheckState, Qt::UniqueConnection);
 
     KTextEditor::MovingInterface *miface = qobject_cast<KTextEditor::MovingInterface *>(doc);
 
@@ -1797,6 +1837,21 @@ void KatePluginSearchView::goToPreviousMatch()
     }
 }
 
+void KatePluginSearchView::setRegexMode(bool enabled)
+{
+    m_ui.useRegExp->setChecked(enabled);
+}
+
+void KatePluginSearchView::setCaseInsensitive(bool enabled)
+{
+    m_ui.matchCase->setChecked(enabled);
+}
+
+void KatePluginSearchView::setExpandResults(bool enabled)
+{
+    m_ui.expandResults->setChecked(enabled);
+}
+
 void KatePluginSearchView::readSessionConfig(const KConfigGroup &cg)
 {
     m_ui.searchCombo->clear();
@@ -1905,7 +1960,6 @@ void KatePluginSearchView::addTab()
     m_ui.resultTabWidget->addTab(res, QString());
     m_ui.resultTabWidget->setCurrentIndex(m_ui.resultTabWidget->count() - 1);
     m_ui.stackedWidget->setCurrentIndex(0);
-    m_ui.resultTabWidget->tabBar()->show();
     m_ui.displayOptions->setChecked(false);
 
     res->treeView->installEventFilter(this);
@@ -1919,13 +1973,18 @@ void KatePluginSearchView::tabCloseRequested(int index)
         cancelDiskFileSearch();
         m_folderFilesList.terminateSearch();
     }
+
     if (m_ui.resultTabWidget->count() > 1) {
-        delete tmp; // remove the tab
-        m_curResults = nullptr;
-    }
-    if (m_ui.resultTabWidget->count() == 1) {
-        m_ui.resultTabWidget->tabBar()->hide();
+        m_ui.resultTabWidget->removeTab(index);
+        if (m_curResults == tmp) {
+            delete m_curResults;
+            m_curResults = nullptr;
+        } else {
+            delete tmp;
+        }
     }
+
+    updateMatchMarks();
 }
 
 void KatePluginSearchView::resultTabChanged(int index)
@@ -1953,6 +2012,7 @@ void KatePluginSearchView::resultTabChanged(int index)
     m_ui.useRegExp->blockSignals(false);
     m_ui.searchPlaceCombo->blockSignals(false);
     searchPlaceChanged();
+    updateMatchMarks();
 }
 
 void KatePluginSearchView::onResize(const QSize &size)
