@@ -268,25 +268,17 @@ void KateConfigDialog::addEditorPages()
 void KateConfigDialog::addPluginPage(KTextEditor::Plugin *plugin)
 {
     for (int i = 0; i < plugin->configPages(); i++) {
-        QFrame *page = new QFrame();
-        QVBoxLayout *layout = new QVBoxLayout(page);
-        layout->setSpacing(0);
-        layout->setContentsMargins(0, 0, 0, 0);
-
-        KTextEditor::ConfigPage *cp = plugin->configPage(i, page);
-        page->layout()->addWidget(cp);
-
-        KPageWidgetItem *item = addPage(page, cp->name());
+        KTextEditor::ConfigPage *cp = plugin->configPage(i, this);
+        KPageWidgetItem *item = addPage(cp, cp->name());
         item->setHeader(cp->fullName());
         item->setIcon(cp->icon());
 
-        PluginPageListItem *info = new PluginPageListItem;
-        info->plugin = plugin;
-        info->pageParent = page;
-        info->pluginPage = cp;
-        info->idInPlugin = i;
-        info->pageWidgetItem = item;
-        connect(info->pluginPage, &KTextEditor::ConfigPage::changed, this, &KateConfigDialog::slotChanged);
+        PluginPageListItem info;
+        info.plugin = plugin;
+        info.pluginPage = cp;
+        info.idInPlugin = i;
+        info.pageWidgetItem = item;
+        connect(info.pluginPage, &KTextEditor::ConfigPage::changed, this, &KateConfigDialog::slotChanged);
         m_pluginPages.insert(item, info);
     }
 }
@@ -294,12 +286,10 @@ void KateConfigDialog::addPluginPage(KTextEditor::Plugin *plugin)
 void KateConfigDialog::removePluginPage(KTextEditor::Plugin *plugin)
 {
     QList<KPageWidgetItem *> remove;
-    for (QHash<KPageWidgetItem *, PluginPageListItem *>::const_iterator it = m_pluginPages.constBegin(); it != m_pluginPages.constEnd(); ++it) {
-        PluginPageListItem *pli = it.value();
-        if (!pli) {
-            continue;
-        }
-        if (pli->plugin == plugin) {
+    for (QHash<KPageWidgetItem *, PluginPageListItem>::const_iterator it = m_pluginPages.constBegin(); it != m_pluginPages.constEnd(); ++it) {
+        const PluginPageListItem &pli = it.value();
+
+        if (pli.plugin == plugin) {
             remove.append(it.key());
         }
     }
@@ -307,11 +297,9 @@ void KateConfigDialog::removePluginPage(KTextEditor::Plugin *plugin)
     qCDebug(LOG_KATE) << remove.count();
     while (!remove.isEmpty()) {
         KPageWidgetItem *wItem = remove.takeLast();
-        PluginPageListItem *pItem = m_pluginPages.take(wItem);
-        delete pItem->pluginPage;
-        delete pItem->pageParent;
+        PluginPageListItem item = m_pluginPages.take(wItem);
+        delete item.pluginPage;
         removePage(wItem);
-        delete pItem;
     }
 }
 
@@ -366,8 +354,8 @@ void KateConfigDialog::slotApply()
         // patch document modified warn state
         const QList<KTextEditor::Document *> &docs = KateApp::self()->documentManager()->documentList();
         for (KTextEditor::Document *doc : docs) {
-            if (qobject_cast<KTextEditor::ModificationInterface *>(doc)) {
-                qobject_cast<KTextEditor::ModificationInterface *>(doc)->setModifiedOnDiskWarning(!m_modNotifications->isChecked());
+            if (auto modIface = qobject_cast<KTextEditor::ModificationInterface *>(doc)) {
+                modIface->setModifiedOnDiskWarning(!m_modNotifications->isChecked());
             }
         }
 
@@ -385,12 +373,9 @@ void KateConfigDialog::slotApply()
 #endif
     }
 
-    for (PluginPageListItem *plugin : qAsConst(m_pluginPages)) {
-        if (!plugin) {
-            continue;
-        }
-        if (plugin->pluginPage) {
-            plugin->pluginPage->apply();
+    for (const PluginPageListItem &plugin : qAsConst(m_pluginPages)) {
+        if (plugin.pluginPage) {
+            plugin.pluginPage->apply();
         }
     }
 
@@ -418,9 +403,9 @@ void KateConfigDialog::slotChanged()
 
 void KateConfigDialog::showAppPluginPage(KTextEditor::Plugin *p, int id)
 {
-    for (PluginPageListItem *plugin : qAsConst(m_pluginPages)) {
-        if ((plugin->plugin == p) && (id == plugin->idInPlugin)) {
-            setCurrentPage(plugin->pageWidgetItem);
+    for (const PluginPageListItem &plugin : qAsConst(m_pluginPages)) {
+        if ((plugin.plugin == p) && (id == plugin.idInPlugin)) {
+            setCurrentPage(plugin.pageWidgetItem);
             break;
         }
     }
