@@ -24,7 +24,6 @@
 #include <KConfigGroup>
 #include <KLocalizedString>
 #include <KMessageBox>
-#include <KRecentFilesAction>
 #include <KToolBar>
 #include <KXMLGUIFactory>
 
@@ -37,7 +36,7 @@
 
 // END Includes
 
-static const qint64 FileSizeAboveToAskUserIfProceedWithOpen = 10 * 1024 * 1024; // 10MB should suffice
+static constexpr qint64 FileSizeAboveToAskUserIfProceedWithOpen = 10 * 1024 * 1024; // 10MB should suffice
 
 KateViewManager::KateViewManager(QWidget *parentW, KateMainWindow *parent)
     : QSplitter(parentW)
@@ -60,7 +59,7 @@ KateViewManager::KateViewManager(QWidget *parentW, KateMainWindow *parent)
     addWidget(vs);
 
     vs->setActive(true);
-    m_viewSpaceList.append(vs);
+    m_viewSpaceList.push_back(vs);
 
     connect(this, &KateViewManager::viewChanged, this, &KateViewManager::slotViewChanged);
 
@@ -82,7 +81,7 @@ KateViewManager::KateViewManager(QWidget *parentW, KateMainWindow *parent)
     // register all already existing documents
     m_blockViewCreationAndActivation = true;
 
-    const QList<KTextEditor::Document *> &docs = KateApp::self()->documentManager()->documentList();
+    const auto &docs = KateApp::self()->documentManager()->documentList();
     for (KTextEditor::Document *doc : docs) {
         documentCreated(doc);
     }
@@ -195,11 +194,11 @@ void KateViewManager::setupActions()
 
 void KateViewManager::updateViewSpaceActions()
 {
-    m_closeView->setEnabled(m_viewSpaceList.count() > 1);
-    m_closeOtherViews->setEnabled(m_viewSpaceList.count() > 1);
-    m_toggleSplitterOrientation->setEnabled(m_viewSpaceList.count() > 1);
-    goNext->setEnabled(m_viewSpaceList.count() > 1);
-    goPrev->setEnabled(m_viewSpaceList.count() > 1);
+    m_closeView->setEnabled(m_viewSpaceList.size() > 1);
+    m_closeOtherViews->setEnabled(m_viewSpaceList.size() > 1);
+    m_toggleSplitterOrientation->setEnabled(m_viewSpaceList.size() > 1);
+    goNext->setEnabled(m_viewSpaceList.size() > 1);
+    goPrev->setEnabled(m_viewSpaceList.size() > 1);
 }
 
 void KateViewManager::slotDocumentNew()
@@ -229,7 +228,7 @@ void KateViewManager::slotDocumentOpen()
      * emit size warning, for local files
      */
     QString fileListWithTooLargeFiles;
-    for (const QUrl &url : urls) {
+    for (const QUrl &url : qAsConst(urls)) {
         if (!url.isLocalFile()) {
             continue;
         }
@@ -271,18 +270,21 @@ void KateViewManager::slotDocumentClose(KTextEditor::Document *document)
 void KateViewManager::slotDocumentClose()
 {
     // no active view, do nothing
-    if (!activeView()) {
+    auto view = activeView();
+    if (!view) {
         return;
     }
 
-    slotDocumentClose(activeView()->document());
+    slotDocumentClose(view->document());
 }
 
 KTextEditor::Document *KateViewManager::openUrl(const QUrl &url, const QString &encoding, bool activate, bool isTempFile, const KateDocumentInfo &docInfo)
 {
     KTextEditor::Document *doc = KateApp::self()->documentManager()->openUrl(url, encoding, isTempFile, docInfo);
 
-    m_mainWindow->addRecentOpenedFile(doc->url());
+    if (!isTempFile) {
+        m_mainWindow->addRecentOpenedFile(doc->url());
+    }
 
     if (activate) {
         activateView(doc);
@@ -293,13 +295,15 @@ KTextEditor::Document *KateViewManager::openUrl(const QUrl &url, const QString &
 
 KTextEditor::Document *KateViewManager::openUrls(const QList<QUrl> &urls, const QString &encoding, bool isTempFile, const KateDocumentInfo &docInfo)
 {
-    const QList<KTextEditor::Document *> docs = KateApp::self()->documentManager()->openUrls(urls, encoding, isTempFile, docInfo);
+    const std::vector<KTextEditor::Document *> docs = KateApp::self()->documentManager()->openUrls(urls, encoding, isTempFile, docInfo);
 
-    for (const KTextEditor::Document *doc : docs) {
-        m_mainWindow->addRecentOpenedFile(doc->url());
+    if (!isTempFile) {
+        for (const KTextEditor::Document *doc : docs) {
+            m_mainWindow->addRecentOpenedFile(doc->url());
+        }
     }
 
-    return docs.isEmpty() ? nullptr : docs.last();
+    return docs.empty() ? nullptr : docs.back();
 }
 
 KTextEditor::View *KateViewManager::openUrlWithView(const QUrl &url, const QString &encoding)
@@ -312,9 +316,7 @@ KTextEditor::View *KateViewManager::openUrlWithView(const QUrl &url, const QStri
 
     m_mainWindow->addRecentOpenedFile(doc->url());
 
-    activateView(doc);
-
-    return activeView();
+    return activateView(doc);
 }
 
 void KateViewManager::openUrl(const QUrl &url)
@@ -346,16 +348,17 @@ void KateViewManager::documentCreated(KTextEditor::Document *doc)
         return;
     }
 
-    if (!activeView()) {
-        activateView(doc);
+    auto view = activeView();
+    if (!view) {
+        view = activateView(doc);
     }
 
     /**
      * check if we have any empty viewspaces and give them a view
      */
-    for (KateViewSpace *vs : qAsConst(m_viewSpaceList)) {
+    for (KateViewSpace *vs : m_viewSpaceList) {
         if (!vs->currentView()) {
-            createView(activeView()->document(), vs);
+            createView(view->document(), vs);
         }
     }
 }
@@ -385,8 +388,8 @@ void KateViewManager::documentsDeleted(const QList<KTextEditor::Document *> &)
     /**
      * try to have active view around!
      */
-    if (!activeView() && !KateApp::self()->documentManager()->documentList().isEmpty()) {
-        createView(KateApp::self()->documentManager()->documentList().last());
+    if (!activeView() && !KateApp::self()->documentManager()->documentList().empty()) {
+        createView(KateApp::self()->documentManager()->documentList().back());
     }
 
     /**
@@ -396,7 +399,7 @@ void KateViewManager::documentsDeleted(const QList<KTextEditor::Document *> &)
         /**
          * check if we have any empty viewspaces and give them a view
          */
-        for (KateViewSpace *vs : qAsConst(m_viewSpaceList)) {
+        for (KateViewSpace *vs : m_viewSpaceList) {
             if (!vs->currentView()) {
                 createView(newActiveView->document(), vs);
             }
@@ -508,23 +511,23 @@ bool KateViewManager::deleteView(KTextEditor::View *view)
     }
 
     // remove view from mapping and memory !!
-    m_views.remove(view);
+    m_views.erase(view);
     delete view;
     return true;
 }
 
 KateViewSpace *KateViewManager::activeViewSpace()
 {
-    for (QList<KateViewSpace *>::const_iterator it = m_viewSpaceList.constBegin(); it != m_viewSpaceList.constEnd(); ++it) {
-        if ((*it)->isActiveSpace()) {
-            return *it;
+    for (auto vs : m_viewSpaceList) {
+        if (vs->isActiveSpace()) {
+            return vs;
         }
     }
 
     // none active, so use the first we grab
-    if (!m_viewSpaceList.isEmpty()) {
-        m_viewSpaceList.first()->setActive(true);
-        return m_viewSpaceList.first();
+    if (!m_viewSpaceList.empty()) {
+        m_viewSpaceList.front()->setActive(true);
+        return m_viewSpaceList.front();
     }
 
     Q_ASSERT(false);
@@ -539,12 +542,10 @@ KTextEditor::View *KateViewManager::activeView()
 
     m_activeViewRunning = true;
 
-    QHashIterator<KTextEditor::View *, ViewData> it(m_views);
-    while (it.hasNext()) {
-        it.next();
-        if (it.value().active) {
+    for (const auto &[view, viewData] : m_views) {
+        if (viewData.active) {
             m_activeViewRunning = false;
-            return it.key();
+            return view;
         }
     }
 
@@ -560,7 +561,7 @@ KTextEditor::View *KateViewManager::activeView()
 
     // last attempt: pick MRU view
     auto views = sortedViews();
-    if (!views.isEmpty()) {
+    if (!views.empty()) {
         KTextEditor::View *v = views.front();
         activateView(v);
         m_activeViewRunning = false;
@@ -575,8 +576,8 @@ KTextEditor::View *KateViewManager::activeView()
 
 void KateViewManager::setActiveSpace(KateViewSpace *vs)
 {
-    if (activeViewSpace()) {
-        activeViewSpace()->setActive(false);
+    if (auto activeSpace = activeViewSpace()) {
+        activeSpace->setActive(false);
     }
 
     vs->setActive(true);
@@ -588,8 +589,8 @@ void KateViewManager::setActiveSpace(KateViewSpace *vs)
 
 void KateViewManager::setActiveView(KTextEditor::View *view)
 {
-    if (activeView()) {
-        m_views[activeView()].active = false;
+    if (auto v = activeView()) {
+        m_views[v].active = false;
     }
 
     if (view) {
@@ -626,8 +627,11 @@ void KateViewManager::activateView(KTextEditor::View *view)
         return;
     }
 
-    Q_ASSERT(m_views.contains(view));
-    if (!m_views[view].active) {
+    auto it = m_views.find(view);
+    Q_ASSERT(it != m_views.end());
+    ViewData &viewData = it->second;
+
+    if (!viewData.active) {
         // avoid flicker
         KateUpdateDisabler disableUpdates(mainWindow());
 
@@ -659,7 +663,7 @@ void KateViewManager::activateView(KTextEditor::View *view)
         }
 
         // remember age of this view
-        m_views[view].lruAge = m_minAge--;
+        viewData.lruAge = m_minAge--;
 
         Q_EMIT viewChanged(view);
 
@@ -679,8 +683,9 @@ KTextEditor::View *KateViewManager::activateView(KTextEditor::Document *d)
     }
 
     // activate existing view if possible
-    if (activeViewSpace()->showView(d)) {
-        activateView(activeViewSpace()->currentView());
+    auto activeSpace = activeViewSpace();
+    if (activeSpace->showView(d)) {
+        activateView(activeSpace->currentView());
         return activeView();
     }
 
@@ -691,33 +696,36 @@ KTextEditor::View *KateViewManager::activateView(KTextEditor::Document *d)
 
 void KateViewManager::slotViewChanged()
 {
-    if (activeView() && !activeView()->hasFocus()) {
-        activeView()->setFocus();
+    auto view = activeView();
+    if (view && !view->hasFocus()) {
+        view->setFocus();
     }
 }
 
 void KateViewManager::activateNextView()
 {
-    int i = m_viewSpaceList.indexOf(activeViewSpace()) + 1;
+    auto it = std::find(m_viewSpaceList.begin(), m_viewSpaceList.end(), activeViewSpace());
+    ++it;
 
-    if (i >= m_viewSpaceList.count()) {
-        i = 0;
+    if (it == m_viewSpaceList.end()) {
+        it = m_viewSpaceList.begin();
     }
 
-    setActiveSpace(m_viewSpaceList.at(i));
-    activateView(m_viewSpaceList.at(i)->currentView());
+    setActiveSpace(*it);
+    activateView((*it)->currentView());
 }
 
 void KateViewManager::activatePrevView()
 {
-    int i = m_viewSpaceList.indexOf(activeViewSpace()) - 1;
-
-    if (i < 0) {
-        i = m_viewSpaceList.count() - 1;
+    auto it = std::find(m_viewSpaceList.begin(), m_viewSpaceList.end(), activeViewSpace());
+    if (it == m_viewSpaceList.begin()) {
+        it = --m_viewSpaceList.end();
+    } else {
+        --it;
     }
 
-    setActiveSpace(m_viewSpaceList.at(i));
-    activateView(m_viewSpaceList.at(i)->currentView());
+    setActiveSpace(*it);
+    activateView((*it)->currentView());
 }
 
 void KateViewManager::documentWillBeDeleted(KTextEditor::Document *doc)
@@ -728,7 +736,7 @@ void KateViewManager::documentWillBeDeleted(KTextEditor::Document *doc)
     QList<KTextEditor::View *> closeList;
     const auto views = doc->views();
     for (KTextEditor::View *v : views) {
-        if (m_views.contains(v)) {
+        if (m_views.find(v) != m_views.end()) {
             closeList.append(v);
         }
     }
@@ -748,8 +756,8 @@ void KateViewManager::closeView(KTextEditor::View *view)
     /**
      * try to have active view around!
      */
-    if (!activeView() && !KateApp::self()->documentManager()->documentList().isEmpty()) {
-        createView(KateApp::self()->documentManager()->documentList().last());
+    if (!activeView() && !KateApp::self()->documentManager()->documentList().empty()) {
+        createView(KateApp::self()->documentManager()->documentList().back());
     }
 
     /**
@@ -759,7 +767,7 @@ void KateViewManager::closeView(KTextEditor::View *view)
         /**
          * check if we have any empty viewspaces and give them a view
          */
-        for (KateViewSpace *vs : qAsConst(m_viewSpaceList)) {
+        for (KateViewSpace *vs : m_viewSpaceList) {
             if (!vs->currentView()) {
                 createView(newActiveView->document(), vs);
             }
@@ -829,7 +837,7 @@ void KateViewManager::splitViewSpace(KateViewSpace *vs, // = 0
         newContainer->setSizes(newSizes);
     }
 
-    m_viewSpaceList.append(vsNew);
+    m_viewSpaceList.push_back(vsNew);
     activeViewSpace()->setActive(false);
     vsNew->setActive(true);
     vsNew->show();
@@ -897,7 +905,7 @@ void KateViewManager::removeViewSpace(KateViewSpace *viewspace)
     }
 
     // abort if this is the last viewspace
-    if (m_viewSpaceList.count() < 2) {
+    if (m_viewSpaceList.size() < 2) {
         return;
     }
 
@@ -927,7 +935,7 @@ void KateViewManager::removeViewSpace(KateViewSpace *viewspace)
     }
 
     // cu viewspace
-    m_viewSpaceList.removeAt(m_viewSpaceList.indexOf(viewspace));
+    m_viewSpaceList.erase(std::remove(m_viewSpaceList.begin(), m_viewSpaceList.end(), viewspace), m_viewSpaceList.end());
     delete viewspace;
 
     // at this point, the splitter has exactly 1 child
@@ -963,12 +971,13 @@ void KateViewManager::removeViewSpace(KateViewSpace *viewspace)
     }
 
     // add the known documents to the current view space to not loose tab buttons
+    auto avs = activeViewSpace();
     for (auto doc : documentList) {
-        activeViewSpace()->registerDocument(doc);
+        avs->registerDocument(doc);
     }
 
     // find the view that is now active.
-    KTextEditor::View *v = activeViewSpace()->currentView();
+    KTextEditor::View *v = avs->currentView();
     if (v) {
         activateView(v);
     }
@@ -998,7 +1007,7 @@ void KateViewManager::slotHideOtherViews(bool hideOthers)
     KateUpdateDisabler disableUpdates(mainWindow());
 
     const KateViewSpace *active = activeViewSpace();
-    for (KateViewSpace *v : qAsConst(m_viewSpaceList)) {
+    for (KateViewSpace *v : m_viewSpaceList) {
         if (active != v) {
             v->setVisible(!hideOthers);
         }
@@ -1061,7 +1070,7 @@ void KateViewManager::restoreViewConfiguration(const KConfigGroup &config)
     restoreSplitter(config.config(), config.name() + QStringLiteral("-Splitter 0"), this, config.name());
 
     // finally, make the correct view from the last session active
-    int lastViewSpace = config.readEntry("Active ViewSpace", 0);
+    size_t lastViewSpace = config.readEntry("Active ViewSpace", 0);
     if (lastViewSpace > m_viewSpaceList.size()) {
         lastViewSpace = 0;
     }
@@ -1083,12 +1092,12 @@ void KateViewManager::restoreViewConfiguration(const KConfigGroup &config)
         KateViewSpace *vs = new KateViewSpace(this, nullptr);
         addWidget(vs);
         vs->setActive(true);
-        m_viewSpaceList.append(vs);
+        m_viewSpaceList.push_back(vs);
 
         /**
          * activate at least one document!
          */
-        activateView(KateApp::self()->documentManager()->documentList().last());
+        activateView(KateApp::self()->documentManager()->documentList().back());
         if (!vs->currentView()) {
             createView(activeView()->document(), vs);
         }
@@ -1125,12 +1134,15 @@ QString KateViewManager::saveSplitterConfig(QSplitter *s, KConfigBase *configBas
         // For KateViewSpaces, ask them to save the file list.
         auto obj = s->widget(it);
         if (auto kvs = qobject_cast<KateViewSpace *>(obj)) {
-            childList.append(QString(viewConfGrp + QStringLiteral("-ViewSpace %1")).arg(m_viewSpaceList.indexOf(kvs)));
-            kvs->saveConfig(configBase, m_viewSpaceList.indexOf(kvs), viewConfGrp);
+            auto it = std::find(m_viewSpaceList.begin(), m_viewSpaceList.end(), kvs);
+            int idx = (int)std::distance(m_viewSpaceList.begin(), it);
+
+            childList.append(QString(viewConfGrp + QStringLiteral("-ViewSpace %1")).arg(idx));
+            kvs->saveConfig(configBase, idx, viewConfGrp);
             // save active viewspace
             if (kvs->isActiveSpace()) {
                 KConfigGroup viewConfGroup(configBase, viewConfGrp);
-                viewConfGroup.writeEntry("Active ViewSpace", m_viewSpaceList.indexOf(kvs));
+                viewConfGroup.writeEntry("Active ViewSpace", idx);
             }
         }
         // for QSplitters, recurse
@@ -1163,7 +1175,7 @@ void KateViewManager::restoreSplitter(const KConfigBase *configBase, const QStri
         // for a viewspace, create it and open all documents therein.
         if (str.startsWith(viewConfGrp + QStringLiteral("-ViewSpace"))) {
             KateViewSpace *vs = new KateViewSpace(this, nullptr);
-            m_viewSpaceList.append(vs);
+            m_viewSpaceList.push_back(vs);
             // make active so that the view created in restoreConfig has this
             // new view space as parent.
             setActiveSpace(vs);
