@@ -179,6 +179,10 @@ int main(int argc, char **argv)
                         QStringLiteral("oss@senarclens.eu"),
                         QStringLiteral("http://find-santa.eu/"));
 
+    aboutData.addCredit(i18n("Tyson Tan"),
+                        i18n("Designer of Kate's mascot 'Kate the Cyber Woodpecker'"),
+                        QString(),
+                        QStringLiteral("https://www.tysontan.com/"));
     aboutData.addCredit(i18n("Matteo Merli"), i18n("Highlighting for RPM Spec-Files, Perl, Diff and more"), QStringLiteral("merlim@libero.it"));
     aboutData.addCredit(i18n("Rocky Scaletta"), i18n("Highlighting for VHDL"), QStringLiteral("rocky@purdue.edu"));
     aboutData.addCredit(i18n("Yury Lebedev"), i18n("Highlighting for SQL"));
@@ -336,8 +340,9 @@ int main(int argc, char **argv)
         }
 
         QStringList kateServices;
-        for (KateRunningInstanceMap::const_iterator it = mapSessionRii.constBegin(); it != mapSessionRii.constEnd(); ++it) {
-            QString serviceName = (*it)->serviceName;
+        for (const auto &[_, katerunninginstanceinfo] : mapSessionRii) {
+            Q_UNUSED(_)
+            QString serviceName = katerunninginstanceinfo.serviceName;
 
             if (currentActivity.length() != 0) {
                 QDBusMessage m = QDBusMessage::createMethodCall(serviceName,
@@ -377,21 +382,19 @@ int main(int argc, char **argv)
             force_new = true;
         } else if (parser.isSet(startSessionOption)) {
             start_session = parser.value(startSessionOption);
-            if (mapSessionRii.contains(start_session)) {
-                serviceName = mapSessionRii[start_session]->serviceName;
+            auto it = mapSessionRii.find(start_session);
+            if (it != mapSessionRii.end()) {
+                serviceName = it->second.serviceName;
                 force_new = false;
                 session_already_opened = true;
             }
         }
 
-        // cleanup map
-        cleanupRunningKateAppInstanceMap(&mapSessionRii);
-
         // if no new instance is forced and no already opened session is requested,
         // check if a pid is given, which should be reused.
         // two possibilities: pid given or not...
         if ((!force_new) && serviceName.isEmpty()) {
-            if ((parser.isSet(usePidOption)) || (!qgetenv("KATE_PID").isEmpty())) {
+            if ((parser.isSet(usePidOption)) || (!qEnvironmentVariableIsEmpty("KATE_PID"))) {
                 QString usePid = (parser.isSet(usePidOption)) ? parser.value(usePidOption) : QString::fromLocal8Bit(qgetenv("KATE_PID"));
 
                 serviceName = QLatin1String("org.kde.kate-") + usePid;
